@@ -1,6 +1,7 @@
 /*
  *  SPDX-FileCopyrightText: 2021 Felipe Kinoshita <kinofhek@gmail.com>
  *  SPDX-FileCopyrightText: 2022 Nate Graham <nate@kde.org>
+ *  SPDX-FileCopyrightText: 2024 Oliver Beard <olib141@outlook.com>
  *
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -47,7 +48,8 @@ int main(int argc, char *argv[])
         // The license this code is released under.
         KAboutLicense::GPL,
         // Copyright Statement.
-        i18nc("@info copyright string", "(c) 2021"));
+        i18nc("@info copyright string", "© 2021–2024, KDE Community"));
+    aboutData.setProgramLogo(QIcon::fromTheme(QStringLiteral("start-here-kde-plasma")));
     aboutData.addAuthor(i18nc("@info:credit", "Felipe Kinoshita"),
                         i18nc("@info:credit", "Author"),
                         QStringLiteral("kinofhek@gmail.com"),
@@ -66,17 +68,37 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     parser.setApplicationDescription(description);
     aboutData.setupCommandLine(&parser);
+
     parser.addOption(QCommandLineOption(QStringLiteral("post-update"), i18n("Display release notes for the current Plasma release.")));
     parser.addOption(QCommandLineOption(QStringLiteral("post-update-beta"), i18n("Display release notes for the current Plasma release, for beta versions.")));
     parser.addOption(QCommandLineOption(QStringLiteral("live-environment"), i18n("Display the live page intended for distro live environments.")));
 
+    QCommandLineOption pagesOption(QStringLiteral("pages"),
+                                   i18n("Specify comma-delimited list of page(s) (by internal name) to be displayed."),
+                                   QStringLiteral("pages"));
+    parser.addOption(pagesOption);
+
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
     auto controller = engine.singletonInstance<Controller *>("org.kde.plasma.welcome", "Controller");
-    if (parser.isSet(QStringLiteral("post-update"))) {
+    if (parser.isSet(QStringLiteral("pages"))) {
+        QStringList pages = parser.value(pagesOption).split(",");
+
+        // Ensure each page ends with ".qml"
+        for (QString &page : pages) {
+            if (!page.endsWith(".qml")) {
+                page.append(".qml");
+            }
+        }
+
+        if (pages.size() != 0) {
+            controller->setMode(Controller::Mode::Pages);
+            controller->setPages(pages);
+        }
+    } else if (parser.isSet(QStringLiteral("post-update"))) {
         controller->setMode(Controller::Mode::Update);
     } else if (parser.isSet(QStringLiteral("post-update-beta"))) {
         controller->setMode(Controller::Mode::Beta);
